// ======================================================================
//
// MenuText.h
// jeff grills
//
// copyright 1997 origin systems inc
//
// ======================================================================

#ifndef MENU_TEXT_H
#define MENU_TEXT_H

// ======================================================================

class StringFile;

#include "Font.h"
#include "MenuElement.h"
#include "Timer.h"
#include "VString.h"

// ======================================================================

class MenuText : public MenuElement
{
protected:

	int                changeEvent;

	Font              *font;
	Font::JustificationRule justifyRule;
	bool               centerInY;

	mutable String     string;       // allow menuDraw to change the string if it hasn't been assigned yet
	bool               isTip;
	Rect               textOutputRect;

private:

	MenuText(const MenuText &);
	MenuText &operator =(const MenuText &);

public:

	MenuText(MenuElement *parent, int maxWidth, int maxHeight, Iff *iff=NULL);
	virtual ~MenuText(void);

	void load(Iff *iff);

	virtual IoResult      event(IoEventStruct *event);
	virtual void          menuDraw(int x, int y) const;

	virtual Font         *getFont(void) const;

	virtual const String &getTextString(void) const;
	const Rect&           getTextOutputRect(void) const;

	virtual void          setFont(Font *newFont);
	virtual void          setTextString(const String &string);
	virtual void          setTextString(int newTextInt);
};

class MenuTextVariable : public MenuText
{
private:

	struct Entry
	{
		Font              *highLight;
		StringFile *section;
		int                textId;
	};

	Entry               *entry;
	int                 numEntries;
	MenuResourceInteger *menuResourceInteger;

private:

	MenuTextVariable(const MenuTextVariable &);
	MenuTextVariable &operator =(const MenuTextVariable &);

public:

	MenuTextVariable(MenuElement *parent, int maxWidth, int maxHeight, Iff *iff = NULL);
	virtual ~MenuTextVariable(void);

	void                    load(Iff *iff);

	virtual const String   &getTextString(void) const;
	virtual Font           *getFont(void) const;
};

class MenuTextInt : public MenuText
{
private:

	MenuResourceInteger *menuResourceInteger;

private:

	MenuTextInt(const MenuTextInt &);
	MenuTextInt &operator =(const MenuTextInt &);

public:

	MenuTextInt(MenuElement *parent, int maxWidth, int maxHeight, Iff *iff = NULL);
	virtual ~MenuTextInt(void);

	void                    load(Iff *iff);

	virtual const String   &getTextString(void) const;
};

// ======================================================================

#endif
